fn read_v2_memory_limit(
cgroups: &[CgroupEntry],
mounts: &[Mountinfo],
) -> Option<MemoryLimit>Available on Linux only.
Finds the mountpoint corresponding to the provided cgroup v2, and reads the memory limits within.
fn read_v2_memory_limit(
cgroups: &[CgroupEntry],
mounts: &[Mountinfo],
) -> Option<MemoryLimit>Finds the mountpoint corresponding to the provided cgroup v2, and reads the memory limits within.